@@ -5,16 +5,22 @@ from ._abc import TimerRequest, InputStream, Context, Out
 from ._eventhub import EventHubEvent
 from ._eventgrid import EventGridEvent, EventGridOutputEvent
 from ._cosmosdb import Document, DocumentList
-from ._http import HttpRequest
-from ._http import HttpResponse
-from ._http_wsgi import WsgiMiddleware
-from .kafka import KafkaEvent, KafkaConverter, KafkaTriggerConverter
-from ._queue import QueueMessage
-from ._servicebus import ServiceBusMessage
+from ._http import HttpRequest, HttpResponse
+from .decorators import (FunctionApp, Function, Blueprint,
+                         DecoratorApi, DataType, AuthLevel,
+                         Cardinality, AccessRights, HttpMethod,
+                         AsgiFunctionApp, WsgiFunctionApp)
 from ._durable_functions import OrchestrationContext, EntityContext
-from .meta import get_binding_registry
+from .decorators.function_app import (FunctionRegister, TriggerApi, BindingApi,
+                                      ExternalHttpFunctionApp)
 from .extension import (ExtensionMeta, FunctionExtensionException,
                         FuncExtensionBase, AppExtensionBase)
+from ._http_wsgi import WsgiMiddleware
+from ._http_asgi import AsgiMiddleware
+from .kafka import KafkaEvent, KafkaConverter, KafkaTriggerConverter
+from .meta import get_binding_registry
+from ._queue import QueueMessage
+from ._servicebus import ServiceBusMessage
 
 # Import binding implementations to register them
 from . import blob  # NoQA
@@ -57,12 +63,30 @@ __all__ = (
 
     # Middlewares
     'WsgiMiddleware',
+    'AsgiMiddleware',
 
     # Extensions
     'AppExtensionBase',
     'FuncExtensionBase',
     'ExtensionMeta',
-    'FunctionExtensionException'
+    'FunctionExtensionException',
+
+    # PyStein implementation
+    'FunctionApp',
+    'Function',
+    'FunctionRegister',
+    'DecoratorApi',
+    'TriggerApi',
+    'BindingApi',
+    'Blueprint',
+    'ExternalHttpFunctionApp',
+    'AsgiFunctionApp',
+    'WsgiFunctionApp',
+    'DataType',
+    'AuthLevel',
+    'Cardinality',
+    'AccessRights',
+    'HttpMethod'
 )
 
-__version__ = '1.7.0'
+__version__ = '1.12.0'
