@@ -15,14 +15,17 @@ from .testutils import CollectionBytes, CollectionString, CollectionSint64
 
 class Kafka(unittest.TestCase):
     SINGLE_KAFKA_DATAUM = '{"Offset":1,"Partition":0,"Topic":"users",'\
-        '"Timestamp":"2020-06-20T04:43:28.998Z","Value":"hello"}'
+        '"Timestamp":"2020-06-20T04:43:28.998Z","Value":"hello", ' \
+                          '"Headers":[{"Key":"test","Value":"1"}]}'
     SINGLE_KAFKA_TIMESTAMP = "2020-06-20T04:43:28.998Z"
     MULTIPLE_KAFKA_TIMESTAMP_0 = "2020-06-20T05:06:25.139Z"
     MULTIPLE_KAFKA_TIMESTAMP_1 = "2020-06-20T05:06:25.945Z"
     MULTIPLE_KAFKA_DATA_0 = '{"Offset":62,"Partition":1,"Topic":"message",'\
-        '"Timestamp":"2020-06-20T05:06:25.139Z","Value":"a"}'
+        '"Timestamp":"2020-06-20T05:06:25.139Z","Value":"a", ' \
+                            '"Headers":[{"Key":"test","Value":"1"}]}'
     MULTIPLE_KAFKA_DATA_1 = '{"Offset":63,"Partition":1,"Topic":"message",'\
-        '"Timestamp":"2020-06-20T05:06:25.945Z","Value":"a"}'
+        '"Timestamp":"2020-06-20T05:06:25.945Z","Value":"a", ' \
+                            '"Headers":[{"Key":"test2","Value":"2"}]}'
 
     def test_kafka_input_type(self):
         check_input_type = (
@@ -194,6 +197,38 @@ class Kafka(unittest.TestCase):
         sys_dict = json.loads(sys)
         self.assertEqual(sys_dict['MethodName'], 'KafkaTriggerMany')
 
+    def test_kafka_convert_single_event_str(self):
+        datum = meta.Datum("dummy_body", "string")
+        result = azf_ka.KafkaConverter.decode(
+            data=datum, trigger_metadata=None)
+
+        self.assertEqual(result.get_body(), b"dummy_body")
+
+    def test_kafka_convert_single_event_bytes(self):
+        datum = meta.Datum(b"dummy_body", "bytes")
+        result = azf_ka.KafkaConverter.decode(
+            data=datum, trigger_metadata=None)
+
+        self.assertEqual(result.get_body(), b"dummy_body")
+
+    def test_kafka_convert_multiple_event_collection_string(self):
+        datum = meta.Datum(CollectionString(["dummy_body1", "dummy_body2"]),
+                           "collection_string")
+        result = azf_ka.KafkaConverter.decode(
+            data=datum, trigger_metadata=None)
+
+        self.assertEqual([result[0].get_body(), result[1].get_body()],
+                         [b"dummy_body1", b"dummy_body2"])
+
+    def test_kafka_convert_multiple_event_collection_bytes(self):
+        datum = meta.Datum(CollectionBytes([b"dummy_body1", b"dummy_body2"]),
+                           "collection_bytes")
+        result = azf_ka.KafkaConverter.decode(
+            data=datum, trigger_metadata=None)
+
+        self.assertEqual([result[0].get_body(), result[1].get_body()],
+                         [b"dummy_body1", b"dummy_body2"])
+
     def _generate_single_kafka_datum(self, datum_type='string'):
         datum = self.SINGLE_KAFKA_DATAUM
         if datum_type == 'bytes':
@@ -202,9 +237,11 @@ class Kafka(unittest.TestCase):
 
     def _generate_multiple_kafka_data(self, data_type='json'):
         data = '[{"Offset":62,"Partition":1,"Topic":"message",'\
-               '"Timestamp":"2020-06-20T05:06:25.139Z","Value":"a"},'\
+               '"Timestamp":"2020-06-20T05:06:25.139Z","Value":"a",' \
+               ' "Headers":[{"Key":"test","Value":"1"}]},'\
                ' {"Offset":63,"Partition":1,"Topic":"message",'\
-               '"Timestamp":"2020-06-20T05:06:25.945Z","Value":"a"}]'
+               '"Timestamp":"2020-06-20T05:06:25.945Z","Value":"a", ' \
+               '"Headers":[{"Key":"test2","Value":"2"}]}]'
         if data_type == 'collection_bytes':
             data = list(
                 map(lambda x: json.dumps(x).encode('utf-8'),
@@ -266,6 +303,10 @@ class Kafka(unittest.TestCase):
             'TopicArray': meta.Datum(
                 CollectionString(['message', 'message']), "collection_string"
             ),
+            'HeadersArray': meta.Datum(
+                json.dumps([['{"Key":"test","Value":"1"}'],
+                            ['{"Key":"test2","Value":"2"}']]), 'json'
+            ),
             'sys': meta.Datum(
                 '{"MethodName":"KafkaTriggerMany",'
                 '"UtcNow":"2020-06-20T05:06:26.5550868Z",'
